# pysorteddict

Provides `SortedDict`, which is a Python sorted dictionary: a Python dictionary in which the keys are always in
ascending order.

[Read more on the homepage.](https://tfpf.github.io/pysorteddict/)

[View the project on PyPI.](https://pypi.org/project/pysorteddict/)

[Explore the source code on GitHub.](https://github.com/tfpf/pysorteddict)

[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)
[![ci](https://github.com/tfpf/pysorteddict/actions/workflows/ci.yml/badge.svg)](https://github.com/tfpf/pysorteddict/actions/workflows/ci.yml)
[![pages](https://github.com/tfpf/pysorteddict/actions/workflows/pages.yml/badge.svg)](https://github.com/tfpf/pysorteddict/actions/workflows/pages.yml)

<p align="center">
 <img src="https://github.com/user-attachments/assets/e9d1e78e-c0fd-4d87-93f6-e293ddef31ba" />
</p>
